aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--CHANGES2
-rw-r--r--RepSys/log.py10
2 files changed, 7 insertions, 5 deletions
diff --git a/CHANGES b/CHANGES
index e1a5e8b..7eb334b 100644
--- a/CHANGES
+++ b/CHANGES
@@ -1,6 +1,8 @@
* 1.6.20
- fixed bad url used when using -v in getsrpm
- make 'repsys submit' without package name or revision number work again
+- the fix for the unreleased commits problem in the previous release was
+ wrong, really fixed it
* 1.6.19
- added complement for SILENT: CLOG, which hides everything that does not
diff --git a/RepSys/log.py b/RepSys/log.py
index b476618..730c674 100644
--- a/RepSys/log.py
+++ b/RepSys/log.py
@@ -425,11 +425,11 @@ def svn2rpm(pkgdirurl, rev=None, size=None, submit=False,
releases.append(release)
prevrevision = relrevision
- # look for commits that have been not submited (released) yet
- # this is done by getting all log entries newer (revision larger)
- # than releaseslog[0] (in the case it exists)
- if releaseslog:
- latest_revision = releaseslog[0].revision
+ # look for commits that have been not submitted (released) yet
+ # this is done by getting all log entries newer (greater revision no.)
+ # than releasesdata[-1] (in the case it exists)
+ if releasesdata:
+ latest_revision = releasesdata[-1][0] # the latest copied rev
else:
latest_revision = 0
notsubmitted = [entry for entry in currentlog